==> SyL-0.9.1.tar.gz: SyL/include/lib/Xml/Rss/Writer/SyL_XmlRssWriter2_0.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssWriter2_0.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * RSS 2.0饹
 *
 * С̡ݲ
 *
 * [channel]
 *   copyright
 *   description
 *   language
 *   link
 *   pubDate <- date
 *   title
 *   category
 *
 * [image]
 *   height
 *   link
 *   title
 *   url
 *   width
 *
 * [textInput]
 *   description
 *   link
 *   name
 *   title
 *
 * [item]
 *   description
 *   link
 *   title
 *   author
 *   category
 *   pubDate <- date
 *   source
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssWriter2_0.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssWriter2_0 extends SyL_XmlRssWriter
{
    /**
     * RSSС
     * 
     * @access protected
     * @var string
     */
    var $version = '2.0';

    /**
     * ͥǤ򥻥åȤ
     * 
     * @access public
     * @param string ̾
     * @param string 
     * @param array °
     */
    function setChannel($name, $value, $attributes=array())
    {
        // ݲ̾Ѵ
        switch ($name) {
        case 'date':
            $name = 'pubDate';
        case 'lastBuildDate':
            $value = $this->convertDateTime($value);
            break;
        }
        parent::setChannel($name, $value, $attributes);
    }

    /**
     * ܤ򥻥åȤ
     * 
     * @access public
     * @param string ̾
     * @param string 
     * @param array °
     */
    function addItem($values, $attributes=array())
    {
        // ݲ̾Ѵ
        foreach (array_keys($values) as $name) {
            switch ($name) {
             case 'date':
                $values['pubDate'] = $this->convertDateTime($values[$name]);
                unset($values[$name]);
                break;
            }
        }
        parent::addItem($values, $attributes);
    }

    /**
     * RSS XML
     * 
     * @access public
     */
    function createXml()
    {
        $this->addStartElement('rss', array('version' => $this->version));
        $this->addStartElement('channel');

        // ͥ
        foreach ($this->channel as $name => $value) {
            $this->createRecursiveElements($name, $value);
        }

        // 
        if (count($this->image) > 0) {
            $this->addStartElement('image');
            foreach ($this->image as $name => $value) {
                $this->createRecursiveElements($name, $value);
            }
            $this->addEndElement();
        }

        // ƥ
        if (count($this->textinput) > 0) {
            $this->addStartElement('textinput');
            foreach ($this->textinput as $name => $value) {
                $this->createRecursiveElements($name, $value);
            }
            $this->addEndElement();
        }

        // ƥ
        foreach ($this->items as $item) {
            $this->addStartElement('item');
            foreach ($item as $name => $value) {
                $this->createRecursiveElements($name, $value);
            }
            $this->addEndElement();
        }

        $this->addEndElement();
        $this->addEndElement();
    }

    /**
     * եޥåȤѴ
     *
     * 2007/03/12 00:00:00 -> Mon, 12 Mar 2007 00:00:00 +0900
     *
     * @access public
     * @param string Ѵ
     * @return string Ѵ
     */
    function convertDateTime($datetime)
    {
        if (preg_match('/^(\d{4})(\-|\/)([0-1][0-9])(\-|\/)([0-3][0-9])( [0-2][0-9]:[0-5][0-9]:[0-5][0-9])?$/', trim($datetime))) {
            $timestamp = @strtotime($datetime);
            if ($timestamp) {
                $datetime = date('D, d M Y H:i:s +0900', $timestamp);
            }
        }
        return $datetime;
    }
}

?>

==> SyL-0.9.2.tar.gz: SyL/include/lib/Xml/Rss/Writer/SyL_XmlRssWriter0_91.php <==
<?php
/**
 * -----------------------------------------------------------------------------
 *
 * SyL - Web Application Framework for PHP
 *
 * PHP version 4 (>= 4.3.x) or 5
 *
 * Copyright (C) 2006-2007 k.watanabe
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *
 * -----------------------------------------------------------------------------
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssWriter0_91.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 * -----------------------------------------------------------------------------
 */

/**
 * RSS 2.0饹
 */
require_once 'SyL_XmlRssWriter2_0.php';

/**
 * RSS 0.91饹
 *
 * С̡ݲ
 *
 * [channel]
 *   copyright
 *   description
 *   language
 *   link
 *   pubDate  <- date
 *   title
 *   category <- (null)
 *
 * [image]
 *   height
 *   link
 *   title
 *   url
 *   width
 *
 * [textInput]
 *   description
 *   link
 *   name
 *   title
 *
 * [item]
 *   description
 *   link
 *   title
 *   author   <- (null)
 *   category <- (null)
 *   date     <- (null)
 *   source   <- (null)
 *
 * @package   SyL
 * @author    k.watanabe <k.watanabe@syl.jp>
 * @copyright 2006-2007 k.watanabe
 * @license   http://www.opensource.org/licenses/lgpl-license.php
 * @version   CVS: $Id: SyL_XmlRssWriter0_91.php,v 1.1 2007/03/17 13:53:07 seasonstream Exp $
 * @link      http://www.syl.jp/
 */
class SyL_XmlRssWriter0_91 extends SyL_XmlRssWriter2_0
{
    /**
     * RSSС
     * 
     * @access protected
     * @var string
     */
    var $version = '0.91';

    /**
     * ͥǤ򥻥åȤ
     * 
     * @access public
     * @param string ̾
     * @param string 
     * @param array °
     */
    function setChannel($name, $value, $attributes=array())
    {
        // ݲ̾Ѵ
        switch ($name) {
        case 'category': return;
        }
        parent::setChannel($name, $value, $attributes);
    }

    /**
     * ܤ򥻥åȤ
     * 
     * @access public
     * @param string ̾
     * @param string 
     * @param array °
     */
    function addItem($values, $attributes=array())
    {
        // ݲ̾Ѵ
        foreach (array_keys($values) as $name) {
            switch ($name) {
            case 'author':
            case 'category':
            case 'date':
            case 'source':
                unset($values[$name]);
                break;
            }
        }
        parent::addItem($values, $attributes);
    }
}

?>
